@@ -87,7 +87,7 @@ function(x, upper, lower, width = 0.02, ...)
     inactive<-im[-ignores]
     normx[nosignal]<-eps*sqrt(n)
     if(trace)
-      cat("LARS Step 0 :\t", sum(nosignal), "Variables with Variance < \eps; dropped for good\n")	#
+      cat("LARS Step 0 :\t", sum(nosignal), "Variables with Variance < eps; dropped for good\n")	#
   }
   else ignores <- NULL #singularities; augmented later as well
   names(normx) <- NULL
